@@ -17,8 +17,11 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import sys, os, locale, gettext
+import gettext
+import locale
 import logging
+import os
+import sys
 from optparse import OptionParser
 
 
@@ -38,6 +41,7 @@ import lazygal
 from lazygal.generators import Album
 import lazygal.config
 import lazygal.eyecandy
+import lazygal.log
 
 
 usage = _("usage: %prog [options] albumdir")
@@ -144,11 +148,14 @@ parser.add_option("", "--pic-sort-by",
                   dest="pic_sort_by", help=_("Sort order for images in a folder: filename, mtime, or exif. Add ':reverse' to reverse the chosen order."))
 parser.add_option("", "--subgal-sort-by",
                   action="store", metavar=_('ORDER'),
-                  dest="subgal_sort_by", help=_("Sort order for sub galleries in a folder: dirname or mtime. Add ':reverse' to reverse the chosen order."))
+                  dest="subgal_sort_by", help=_("Sort order for sub galleries in a folder: dirname, exif or mtime. Add ':reverse' to reverse the chosen order."))
+parser.add_option("", "--filter-by-tag", type="string",
+                  action="append", metavar=_('TAG'),
+                  dest="filter_by_tag", help=_("Only include in the gallery pics whose IPTC keywords match the supplied filter(s)."))
 parser.add_option("", "--keep-gps-data",
-                    action="store_true",
-                    dest="keep_gps",
-                    help=_("Do not remove GPS location tags from EXIF metadata. Mostly useful with holiday photos."))
+                  action="store_true",
+                  dest="keep_gps",
+                  help=_("Do not remove GPS location tags from EXIF metadata. Mostly useful with holiday photos."))
 (options, args) = parser.parse_args()
 
 if options.show_version:
@@ -176,7 +183,7 @@ if options.check_all_dirs:
     cmdline_config.set('runtime', 'check-all-dirs', 'Yes')
 
 if options.dest_dir is not None:
-    cmdline_config.set('global', 'destdir',
+    cmdline_config.set('global', 'output-directory',
                        options.dest_dir.decode(sys.getfilesystemencoding()))
 if options.force_gen_pages:
     cmdline_config.set('global', 'force-gen-pages', 'Yes')
@@ -206,6 +213,8 @@ if options.pic_sort_by is not None:
     cmdline_config.set('webgal', 'sort-medias', options.pic_sort_by)
 if options.subgal_sort_by is not None:
     cmdline_config.set('webgal', 'sort-subgals', options.subgal_sort_by)
+if options.filter_by_tag is not None:
+    cmdline_config.set('webgal', 'filter-by-tag', options.filter_by_tag)
 if options.original:
     cmdline_config.set('webgal', 'original', 'Yes')
 if options.orig_base is not None:
@@ -233,19 +242,35 @@ if options.tpl_vars is not None:
         cmdline_config.set('template-vars',
                            name, value.decode(sys.stdin.encoding))
 
-logging.basicConfig(format='%(message)s', level=logging.INFO)
+logger = logging.getLogger()
+logger.setLevel(logging.INFO)
+output_log = lazygal.log.ProgressConsoleHandler()
+output_log.setFormatter(logging.Formatter('%(message)s'))
+logger.addHandler(output_log)
 
 try:
     album = Album(source_dir, cmdline_config)
 except ValueError, e:
     print unicode(e)
     sys.exit(1)
+else:
+    if sys.stdout.isatty():
+        progress = lazygal.generators.AlbumGenProgress(\
+            len(album.stats()['bydir'].keys()), album.stats()['total'])
+
+        def update_progress():
+            output_log.update_progress(unicode(progress))
+        progress.updated = update_progress
+        progress.updated()
+    else:
+        progress = None
+
 
 if options.metadata:
     album.generate_default_metadata()
 else:
     try:
-        album.generate()
+        album.generate(progress=progress)
     except KeyboardInterrupt:
         print >> sys.stderr, _("Interrupted.")
         sys.exit(1)
