@@ -15,10 +15,10 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
-import os
-import sys, urllib
 import email.utils
+import os
+import sys
+import urllib
 from xml.etree import cElementTree as ET
 
 
@@ -33,13 +33,13 @@ class RSS20:
         self.__maxitems = maxitems
 
     def __get_root_and_channel(self, feed_filename):
-        root = ET.Element('rss', {'version'    : '2.0',
-                                  'xmlns:atom' : 'http://www.w3.org/2005/Atom'})
+        root = ET.Element('rss', {'version'   : '2.0',
+                                  'xmlns:atom': 'http://www.w3.org/2005/Atom'})
 
         channel = ET.SubElement(root, 'channel')
-        ET.SubElement(channel, 'title' ).text = self.title
-        ET.SubElement(channel, 'link' ).text = self.__url_quote(self.link)
-        ET.SubElement(channel, 'description' ).text = self.description
+        ET.SubElement(channel, 'title').text = self.title
+        ET.SubElement(channel, 'link').text = self.__url_quote(self.link)
+        ET.SubElement(channel, 'description').text = self.description
         ET.SubElement(channel, 'atom:link', {'href': self.link + feed_filename,
                                              'rel' : 'self',
                                              'type': 'application/rss+xml'})
@@ -56,12 +56,12 @@ class RSS20:
         item = {}
         item['title'] = title
         item['link'] = link
-        item['contents'] =  contents
+        item['contents'] = contents
         item['timestamp'] = timestamp
 
         i = 0
         while i < len(self.items)\
-        and self.__item_older(item, self.items[i]) > 0:
+                and self.__item_older(item, self.items[i]) > 0:
             i = i + 1
 
         if i < self.__maxitems:
@@ -74,9 +74,9 @@ class RSS20:
     def dump(self, path):
         (root, channel) = self.__get_root_and_channel(os.path.basename(path))
 
-        pubdate = ET.SubElement(channel, 'pubDate' )
+        pubdate = ET.SubElement(channel, 'pubDate')
 
-        self.items.sort(lambda x,y: int(x['timestamp'] - y['timestamp']))
+        self.items.sort(lambda x, y: int(x['timestamp'] - y['timestamp']))
         for item in self.items:
             rssitem = ET.SubElement(channel, 'item')
             ET.SubElement(rssitem, 'title').text = item['title']
