@@ -16,13 +16,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os
-import glob
 import locale
 import logging
 import gc
 import genshi
 import sys
 import re
+import shutil
 
 from config import LazygalConfig, LazygalWebgalConfig
 from config import USER_CONFIG_PATH, LazygalConfigDeprecated
@@ -291,8 +291,15 @@ class WebalbumVideoTask(WebalbumMediaTask):
 
     def get_resized(self, size_name):
         if not self.webvideo:
-            self.webvideo = genmedia.WebVideo(self.webgal, self.media,
-                                              self.webgal.default_size_name)
+            if self.webgal.newsizers[genmedia.VIDEO_SIZE_NAME] == 'original'\
+            and self.media.extension == '.webm':
+                # do not transcode webm videos
+                self.webvideo = self.get_original_or_symlink()
+            else:
+                self.webvideo = genmedia.WebVideo(self.webgal, self.media,
+                                                  genmedia.VIDEO_SIZE_NAME,
+                                                  self.webgal.progress)
+
         return self.webvideo
 
 
@@ -308,8 +315,12 @@ class WebalbumDir(make.FileMakeObject):
 
         super(WebalbumDir, self).__init__(self.path)
 
+        self.progress = progress
+
         self.add_dependency(self.source_dir)
-        self.subgals = subgals
+        self.subgals = [s for s in subgals if s.get_all_media_count() > 0]
+        for srcdir in self.source_dir.subdirs:
+            self.add_dependency(srcdir)
         self.album = album
         self.feed = None
 
@@ -318,15 +329,6 @@ class WebalbumDir(make.FileMakeObject):
         self.config = LazygalWebgalConfig(self.album.config)
         self.__configure()
 
-        # Create the directory if it does not exist
-        if not os.path.isdir(self.path) and (self.source_dir.get_media_count() > 0):
-            logging.info(_("  MKDIR %%WEBALBUMROOT%%/%s")
-                         % self.source_dir.strip_root())
-            logging.debug("(%s)" % self.path)
-            os.makedirs(self.path, mode=0755)
-            # Directory did not exist, mark it as so
-            self.stamp_delete()
-
         tagfilters = self.config.getlist('webgal', 'filter-by-tag')
 
         self.medias = []
@@ -364,6 +366,14 @@ class WebalbumDir(make.FileMakeObject):
             self.medias.append(media_task)
             self.add_dependency(media_task)
 
+        # Create the directory if it does not exist
+        if not os.path.isdir(self.path) and (self.get_media_count() > 0):
+            logging.info(_("  MKDIR %%WEBALBUMROOT%%/%s")
+                         % self.source_dir.strip_root())
+            logging.debug("(%s)" % self.path)
+            os.makedirs(self.path, mode=0755)
+            self.stamp_delete() # Directory did not exist, mark it as so
+
         if self.config.getboolean('webgal', 'dirzip')\
                 and self.get_media_count() > 1:
             self.dirzip = genfile.WebalbumArchive(self)
@@ -373,7 +383,7 @@ class WebalbumDir(make.FileMakeObject):
 
         self.index_pages = []
 
-        if not self.should_be_flattened():
+        if (self.get_all_media_count() > 0) and not self.should_be_flattened():
             self.break_task = SubgalBreak(self)
 
             if self.thumbs_per_page > 0:
@@ -391,8 +401,6 @@ class WebalbumDir(make.FileMakeObject):
         else:
             self.break_task = None
 
-        self.progress = progress
-
     def __parse_browse_sizes(self, sizes_string):
         for single_def in sizes_string.split(','):
             name, string_size = single_def.split('=')
@@ -407,6 +415,8 @@ class WebalbumDir(make.FileMakeObject):
     def __parse_size(self, size_name, size_string):
         if size_string == '0x0':
             self.newsizers[size_name] = 'original'
+        elif size_string in self.newsizers:
+            pass # size reference, do nothing
         else:
             try:
                 self.newsizers[size_name] = newsize.get_newsizer(size_string)
@@ -455,6 +465,8 @@ class WebalbumDir(make.FileMakeObject):
         self.__parse_browse_sizes(self.config.get('webgal', 'image-size'))
         self.__parse_size(genmedia.THUMB_SIZE_NAME,
                           self.config.get('webgal', 'thumbnail-size'))
+        self.__parse_size(genmedia.VIDEO_SIZE_NAME,
+                          self.config.get('webgal', 'video-size'))
         self.default_size_name = self.browse_sizes[0]
 
         self.tpl_vars = self.__load_tpl_vars()
@@ -563,6 +575,12 @@ class WebalbumDir(make.FileMakeObject):
                     typed_media_count += 1
             return typed_media_count
 
+    def get_all_media_count(self):
+        count = len(self.medias)
+        for subgal in self.subgals:
+            count += subgal.get_all_media_count()
+        return count
+
     def get_all_medias_tasks(self):
         all_medias = list(self.medias)  # We want a copy here.
         for subgal in self.subgals:
@@ -614,6 +632,9 @@ class WebalbumDir(make.FileMakeObject):
             return ''
 
     def list_foreign_files(self):
+        if not os.path.isdir(self.path):
+            return []
+
         foreign_files = []
 
         # Check dest for junk files
@@ -622,7 +643,7 @@ class WebalbumDir(make.FileMakeObject):
             extra_files.append(os.path.join(self.path,
                                             DEST_SHARED_DIRECTORY_NAME))
 
-        dirnames = [d.name for d in self.source_dir.subdirs]
+        dirnames = [d.source_dir.name for d in self.subgals]
         expected_dirs = map(lambda dn: os.path.join(self.path, dn), dirnames)
         for dest_file in os.listdir(self.path):
             dest_file = os.path.join(self.path, dest_file)
@@ -638,7 +659,7 @@ class WebalbumDir(make.FileMakeObject):
 
     def build(self):
         for dest_file in self.list_foreign_files():
-            self.album.cleanup(dest_file)
+            self.album.cleanup(dest_file, self.path)
 
     def make(self, force=False):
         needed_build = self.needs_build()
@@ -650,7 +671,8 @@ class WebalbumDir(make.FileMakeObject):
         # if we regenerated without adding/removing pictures (to take into
         # account a rotation for example). This is why we force directory mtime
         # update here if something has been built.
-        if needed_build: os.utime(self.path, None)
+        if needed_build and os.path.isdir(self.path):
+            os.utime(self.path, None)
 
     def media_done(self):
         if self.progress is not None:
@@ -672,13 +694,8 @@ class SharedFiles(make.FileMakeObject):
         super(SharedFiles, self).__init__(self.path)
 
         self.expected_shared_files = []
-        for shared_file in glob.glob(
-                os.path.join(self.album.theme.tpl_dir,
-                             tpl.THEME_SHARED_FILE_PREFIX + '*')):
-            shared_file_name = os.path.basename(shared_file).\
-                replace(tpl.THEME_SHARED_FILE_PREFIX, '')
-            shared_file_dest = os.path.join(self.path,
-                                            shared_file_name)
+        for shared_file, shared_file_rel_dest in self.album.theme.shared_files:
+            shared_file_dest = os.path.join(self.path, shared_file_rel_dest)
 
             if self.album.theme.tpl_loader.is_known_template_type(shared_file):
                 sf = genpage.SharedFileTemplate(album, shared_file,
@@ -698,7 +715,7 @@ class SharedFiles(make.FileMakeObject):
         for present_file in os.listdir(self.path):
             file_path = os.path.join(self.path, present_file)
             if file_path not in self.expected_shared_files:
-                self.album.cleanup(file_path)
+                self.album.cleanup(file_path, self.path)
 
 
 class AlbumGenProgress(object):
@@ -710,6 +727,8 @@ class AlbumGenProgress(object):
         self._medias_total = medias_total
         self._medias_done = 0
 
+        self._task_percent = None
+
     def dir_done(self):
         self._dirs_done = self._dirs_done + 1
         self.updated()
@@ -718,13 +737,26 @@ class AlbumGenProgress(object):
         self._medias_done = self._medias_done + how_many
         self.updated()
 
+    def set_task_progress(self, percent):
+        self._task_percent = percent
+        self.updated()
+
+    def set_task_done(self):
+        self._task_percent = None
+        self.updated()
+
     def __unicode__(self):
-        return _("Progress: dir %d/%d (%d%%), media %d/%d (%d%%)")\
-               % (self._dirs_done, self._dirs_total,
-                  100 * self._dirs_done // self._dirs_total,
-                  self._medias_done, self._medias_total,
-                  100 * self._medias_done // self._medias_total,
-                 )
+        msg = _("Progress: dir %d/%d (%d%%), media %d/%d (%d%%)")\
+              % (self._dirs_done, self._dirs_total,
+                 100 * self._dirs_done // self._dirs_total,
+                 self._medias_done, self._medias_total,
+                 100 * self._medias_done // self._medias_total,
+                )
+
+        if self._task_percent is not None:
+            msg = msg + _(", current task %d%%") % self._task_percent
+
+        return msg
 
     def updated(self):
         pass
@@ -776,14 +808,15 @@ class Album(object):
     def is_in_sourcetree(self, path):
         return pathutils.is_subdir_of(self.source_dir, path)
 
-    def cleanup(self, file_path):
-        text = ''
-        if self.clean_dest and not os.path.isdir(file_path):
-            os.unlink(file_path)
-            text = ''
-        else:
-            text = _('you should ')
-        logging.info(_('  %sRM %s') % (text, file_path))
+    def cleanup(self, file_path, context_path):
+        if self.clean_dest:
+            # Do not delete something out of dest-dir.
+            assert pathutils.is_subdir_of(context_path, file_path)
+            if os.path.isdir(file_path):
+                shutil.rmtree(file_path)
+            else:
+                os.unlink(file_path)
+            logging.info('RM %s' % (file_path))
 
     def generate_default_metadata(self):
         """
@@ -866,11 +899,6 @@ class Album(object):
                 # Use root config tpl vars for shared files
                 tpl_vars = destgal.tpl_vars
 
-            if source_dir.get_all_medias_count() < 1:
-                logging.debug(_("(%s) and childs have no known medias, skipped")
-                              % source_dir.path)
-                continue
-
             if not source_dir.is_album_root():
                 container_dirname = os.path.dirname(root)
                 if container_dirname not in dir_heap:
