@@ -64,6 +64,8 @@ class GstVideoOpener(object):
     def __init__(self, input_file):
         self.input_file = input_file
 
+        self.progress = None
+
         self.pipeline = gst.Pipeline()
         self.running = False
 
@@ -104,6 +106,9 @@ class GstVideoOpener(object):
         msg = gst.message_new_application(self.pipeline, gst.Structure(msg_txt))
         self.pipeline.get_bus().post(msg)
 
+    def set_progress(self, progress):
+        self.progress = progress
+
     def monitor_progress(self):
         # check if CTRL+C'd
         if interrupted:
@@ -113,6 +118,10 @@ class GstVideoOpener(object):
         stalled = False
         try:
             current_position, fmt = self.pipeline.query_position(gst.FORMAT_TIME)
+            if self.media_duration is None:
+                self.media_duration, fmt = self.pipeline.query_duration(gst.FORMAT_TIME)
+            if self.progress is not None:
+                self.progress.set_task_progress(100 * current_position // self.media_duration)
         except gst.QueryError:
             pass
         else:
@@ -135,8 +144,9 @@ class GstVideoOpener(object):
         self.pipeline.set_state(gst.STATE_PLAYING)
         self.running = True
         self.last_position = None
+        self.media_duration = None
 
-        gobject.timeout_add(250, self.monitor_progress)
+        gobject.timeout_add(1000, self.monitor_progress)
 
         while self.running:
             message = self.pipeline.get_bus().poll(gst.MESSAGE_ANY, -1)
@@ -157,6 +167,9 @@ class GstVideoOpener(object):
                         self.__stop_pipeline()
                         raise TranscodeError('Pipeline is stalled, this is a problem either in gst or in lazygal\'s use of gst')
 
+        if self.progress is not None:
+            self.progress.set_task_done()
+
     def stop_pipeline(self):
         msg = gst.message_new_application(self.pipeline,
                                           gst.Structure('aborded_playback'))
@@ -252,22 +265,25 @@ class GstVideoTranscoder(GstVideoReader):
         # Video
         self.decode_video()
 
-        self.videoscale = gst.element_factory_make('videoscale', 'videoscale')
-        self.videoscale.set_property('method', 'bilinear')
-        self.pipeline.add(self.videoscale)
-        self.ff.link(self.videoscale)
-        caps_str = "video/x-raw-yuv"
-        if width is not None and height is not None:
-            caps_str += ", width=%d, height=%d" % (width, height)
-        caps = gst.Caps(caps_str)
-        self.caps_filter = gst.element_factory_make("capsfilter", "filter")
-        self.caps_filter.set_property("caps", caps)
-        self.pipeline.add(self.caps_filter)
-        self.videoscale.link(self.caps_filter)
-
         self.videoenc = gst.element_factory_make(videocodec, 'videoenc')
         self.pipeline.add(self.videoenc)
-        self.caps_filter.link(self.videoenc)
+
+        if width is not None and height is not None:
+            self.videoscale = gst.element_factory_make('videoscale',
+                                                       'videoscale')
+            self.videoscale.set_property('method', 'bilinear')
+            self.pipeline.add(self.videoscale)
+            self.ff.link(self.videoscale)
+            caps_str = "video/x-raw-yuv"
+            caps_str += ", width=%d, height=%d" % (width, height)
+            caps = gst.Caps(caps_str)
+            self.caps_filter = gst.element_factory_make("capsfilter", "filter")
+            self.caps_filter.set_property("caps", caps)
+            self.pipeline.add(self.caps_filter)
+            self.videoscale.link(self.caps_filter)
+            self.caps_filter.link(self.videoenc)
+        else:
+            self.ff.link(self.videoenc)
 
         voqueue = gst.element_factory_make("queue")
         self.pipeline.add(voqueue)
