@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import re
+
 import os
 import time
 import locale
@@ -209,6 +209,9 @@ class VideoFile(MediaFile):
     def get_size(self):
         inspector = mediautils.GstVideoInfo(self.path)
         inspector.inspect()
+        if inspector.broken is True:
+            self.broken = True
+            return (None, None)
         return inspector.videowidth, inspector.videoheight
 
     def has_reliable_date(self):
@@ -217,6 +220,9 @@ class VideoFile(MediaFile):
     def get_date_taken(self):
         return self.get_datetime()
 
+    def info(self):
+        return None
+
 
 class MediaHandler(object):
 
@@ -265,40 +271,22 @@ class Directory(File):
 
         self.human_name = self.album._str_humanize(self.name)
 
-        tagfilters = album.config.getlist('webgal', 'filter-by-tag')
-
         media_handler = MediaHandler(self.album)
         self.medias = []
         self.medias_names = []
         for filename in self.filenames:
             media_path = os.path.join(self.path, filename)
+
+            if not os.path.isfile(media_path):
+                logging.info(_("  Ignoring %s, cannot open file (broken symlink?).")
+                             % filename)
+                logging.debug("(%s)" % os.path.join(self.path, filename))
+                continue
+
             media = media_handler.get_media(media_path)
             if media:
-
-                # tag-filtering is requested
-                if len(tagfilters) > 0:
-                    res = True
-                    for tagf in tagfilters:
-                        # concatenate the list of tags as a string of words,
-                        # space-separated.  to ensure that we match the full
-                        # keyword and not only a subpart of it, we also surround
-                        # the matching pattern with spaces
-
-                        # we look for tag words, partial matches are not wanted
-                        regex = re.compile(r"\b" + tagf + r"\b")
-
-                        kwlist = ' '.join(media.info().get_keywords())
-                        if re.search(regex, kwlist) is None:
-                            res = False
-                            break
-                    if res is True:
-                        self.medias_names.append(filename)
-                        self.medias.append(media)
-
-                # no tag-filtering  
-                else:
-                        self.medias_names.append(filename)
-                        self.medias.append(media)
+                self.medias_names.append(filename)
+                self.medias.append(media)
             elif not self.is_metadata(filename) and\
                     filename != SOURCEDIR_CONFIGFILE:
                 logging.info(_("  Ignoring %s, format not supported.")
