@@ -16,7 +16,8 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-import time, locale
+import time
+import locale
 
 
 class Datetime(object):
