@@ -24,7 +24,6 @@ from __init__ import LazygalTestGen
 from lazygal.generators import WebalbumDir
 from lazygal.sourcetree import Directory
 from lazygal.genpage import WebalbumIndexPage
-from lazygal import pyexiv2api as pyexiv2
 
 
 class TestDeps(LazygalTestGen):
@@ -41,14 +40,16 @@ class TestDeps(LazygalTestGen):
         dest_path = os.path.join(self.tmpdir, 'dst')
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
-        self.assertTrue(dest_subgal.needs_build(),
-               'Webalbum subgal has not been built and does not need build.')
+        self.assertTrue(
+            dest_subgal.needs_build(),
+            'Webalbum subgal has not been built and does not need build.')
 
         self.album.generate(dest_path)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
-        self.assertFalse(dest_subgal.needs_build(),
-            'Webalbum subgal has been built and does need build because of %s.'\
+        self.assertFalse(
+            dest_subgal.needs_build(),
+            'Webalbum subgal has been built and does need build because of %s.'
             % str(dest_subgal.needs_build(True)))
 
     def test_dirmetadata_update(self):
@@ -72,19 +73,21 @@ class TestDeps(LazygalTestGen):
         self.album.generate(dest_path)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
-        self.assertFalse(dest_subgal.needs_build(),
-            'Webalbum subgal has been built and does need build because of %s.'\
+        self.assertFalse(
+            dest_subgal.needs_build(),
+            'Webalbum subgal has been built and does need build because of %s.'
             % str(dest_subgal.needs_build(True)))
 
         # touch the description file
-        time.sleep(1) # ensure time diffrence for some systems
+        time.sleep(1)  # ensure time diffrence for some systems
         os.utime(os.path.join(source_subgal.path, 'album_description'), None)
         # New objects in order to probe filesystem
         source_subgal = Directory(subgal_path, [], ['subgal_img.jpg'],
                                   self.album)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
-        self.assertTrue(dest_subgal.needs_build(),
+        self.assertTrue(
+            dest_subgal.needs_build(),
             'Webalbum subgal should need build because of updated dir md.')
 
     def test_subgal_update(self):
@@ -99,8 +102,9 @@ class TestDeps(LazygalTestGen):
         self.album.generate(dest_path)
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
-        self.assertFalse(dest_subgal.needs_build(),
-            'Webalbum subgal has been built and does need build because of %s.'\
+        self.assertFalse(
+            dest_subgal.needs_build(),
+            'Webalbum subgal has been built and does need build because of %s.'
             % str(dest_subgal.needs_build(True)))
 
         self.add_img(source_subgal.path, 'subgal_img2.jpg')
@@ -111,21 +115,24 @@ class TestDeps(LazygalTestGen):
         dest_subgal = WebalbumDir(source_subgal, [], self.album, dest_path)
 
         # Subgal should need build.
-        self.assertTrue(dest_subgal.needs_build(),
+        self.assertTrue(
+            dest_subgal.needs_build(),
             'Webalbum subgal should need build because of added pic in subgal.')
 
         # Parent directory should need build.
         source_gal = Directory(self.source_dir, [source_subgal], [], self.album)
         dest_gal = WebalbumDir(source_gal, [dest_subgal], self.album, dest_path)
-        self.assertTrue(dest_gal.needs_build(),
+        self.assertTrue(
+            dest_gal.needs_build(),
             'Webalbum gal should need build because of added pic in subgal.')
 
         # Parent directory should need build.
         parent_index = WebalbumIndexPage(dest_gal, 'small', 0,
                                          [dest_subgal],
                                          [(dest_subgal, dest_subgal.medias)])
-        self.assertTrue(parent_index.needs_build(),
-         'Webalbum gal index should need build because of added pic in subgal.')
+        self.assertTrue(
+            parent_index.needs_build(),
+            'Webalbum gal index should need build because of added pic in subgal.')
 
 
 if __name__ == '__main__':
