@@ -68,7 +68,7 @@ class TestGenerators(LazygalTestGen):
                    'subgal_img_medium.jpg'):
             self.assertTrue(os.path.isfile(os.path.join(dest_subgal_path, fn)))
 
-    def test_filecleanup(self):
+    def test_spot_foreign_files(self):
         """
         Files that are not part of what was generated or updated shall be
         spotted.
@@ -83,6 +83,7 @@ class TestGenerators(LazygalTestGen):
         # add a thumbs that should not be there
         self.add_img(dest_path, 'extra_thumb.jpg')
         self.add_img(os.path.join(dest_path, 'subgal'), 'extra_thumb2.jpg')
+        os.mkdir(os.path.join(dest_path, 'extra_dir'))
 
         # remove a pic in source_dir
         os.unlink(os.path.join(self.source_dir, 'subgal', 'img6.jpg'))
@@ -101,12 +102,114 @@ class TestGenerators(LazygalTestGen):
                         ]
                        )
         self.assertEqual(sorted(dest_subgal.list_foreign_files()),
-                         sorted(expected))
-
+                        sorted(expected))
         source_gal = Directory(self.source_dir, [source_subgal], [], self.album)
         dest_gal = WebalbumDir(source_gal, [dest_subgal], self.album, dest_path)
+        expected =  map(lambda fn:
+                        unicode(os.path.join(dest_path, fn)),
+                        ['extra_thumb.jpg', 'extra_dir']
+                       )
         self.assertEqual(sorted(dest_gal.list_foreign_files()),
-                         [os.path.join(dest_path, 'extra_thumb.jpg')])
+                         sorted(expected))
+
+    def test_cleanup(self):
+        """
+        Check that the foreign files are deleted.
+        """
+        config = lazygal.config.LazygalConfig()
+        config.set('global', 'clean-destination', "true")
+        self.setup_album(config)
+
+        pics = ['img%02d.jpg' % i for i in range(4, 8)]
+        source_subgal = self.setup_subgal('subgal', pics)
+
+        dest_path = self.get_working_path()
+
+        self.album.generate(dest_path)
+
+        # add thumbs and directories that should not be there
+        self.add_img(dest_path, 'extra_thumb.jpg')
+        self.add_img(os.path.join(dest_path, 'subgal'), 'extra_thumb2.jpg')
+        os.mkdir(os.path.join(dest_path, 'extra_dir'))
+        self.add_img(os.path.join(dest_path, 'extra_dir'), 'extra_thumb3.jpg')
+
+        # remove a pic in source_dir
+        os.unlink(os.path.join(self.source_dir, 'subgal', 'img06.jpg'))
+
+        self.album.generate(dest_path)
+
+        try:
+            for f in ['extra_thumb2.jpg',
+                    'img06_thumb.jpg', 'img06_small.jpg', 'img06_medium.jpg',
+                    'img06.html', 'img06_medium.html',
+                    ]:
+                self.assertFalse(os.path.isfile(os.path.join(dest_path, 'subgal', f)))
+
+            for f in ['extra_thumb.jpg']:
+                self.assertFalse(os.path.isfile(os.path.join(dest_path, f)))
+            for f in ['extra_dir']:
+                self.assertFalse(os.path.isdir(os.path.join(dest_path, f)))
+        except AssertionError:
+            print "\n contents of dest_path : "
+            print sorted(os.listdir(dest_path))
+            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            raise
+
+    def test_clean_empty_dirs(self):
+        """
+        Check that empty dirs at destination are removed
+        .
+        This case might happen when (1) the destination dir is created according
+        to the contents of source_dir.
+        (2) Then source_dir becomes empty, either because all the images have
+        been removed, or because tag filtering is applied with different
+        settings. The next lazygal generation should remove the destination dir.
+        """
+        config = lazygal.config.LazygalConfig()
+        config.set('global', 'clean-destination', "true")
+        self.setup_album(config)
+
+        pics = ['img.jpg']
+        source_subgal = self.setup_subgal('subgal', pics)
+
+        dest_path = self.get_working_path()
+        self.album.generate(dest_path)
+
+        # all the files in subgal should be here after the first generation
+        try:
+            for f in ['img_thumb.jpg', 'img_small.jpg', 'img_medium.jpg',
+                     'img.html', 'img_medium.html',
+                     ]:
+                self.assertTrue(os.path.isfile(os.path.join(dest_path, 'subgal', f)))
+
+            for f in ['subgal']:
+                self.assertTrue(os.path.isdir(os.path.join(dest_path, f)))
+        except AssertionError:
+            print "\n contents of dest_path after first generation: "
+            print sorted(os.listdir(dest_path))
+            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            raise
+
+        # remove the pic in subgal, and force a new generation
+        os.unlink(os.path.join(self.source_dir, 'subgal', 'img.jpg'))
+        self.album.generate(dest_path)
+
+        # now the subdirectory subgal and its contents should no longer be there
+        try:
+            for f in ['img.jpg',
+                     'img_thumb.jpg', 'img_small.jpg', 'img_medium.jpg',
+                     'img.html', 'img_medium.html',
+                     ]:
+                self.assertFalse(os.path.isfile(os.path.join(dest_path, 'subgal', f)))
+
+            for f in ['subgal']:
+                self.assertFalse(os.path.isdir(os.path.join(dest_path, f)))
+        except AssertionError:
+            print "\n contents of dest_path after the second generation: "
+            print sorted(os.listdir(dest_path))
+            print sorted(os.listdir(os.path.join(dest_path, 'subgal')))
+            raise
+
 
     @skip(not has_symlinks(), 'symlinks not supported on platform')
     def test_originals_symlinks(self):
@@ -233,48 +336,53 @@ class TestGenerators(LazygalTestGen):
         config.set('webgal', 'filter-by-tag', 'lazygal')
         self.setup_album(config)
 
-        # good pictures will be pushed on the destination, false pictures
+        # tagfound pictures will be pushed on the destination, tagnotfound pictures
         # should be filtered out.
-        # The sub-directory 'subfalse' should not be created on the destination
+        # The sub-directory 'sdir_tagnotfound' should not be created on the destination
         # side, because it should be empty.
-        good_path         = self.add_img(self.source_dir, 'good.jpg')
-        good_path2        = self.add_img(self.source_dir, 'good2.jpg')
-        false_path        = self.add_img(self.source_dir, 'false.jpg')
-        subgood           = self.setup_subgal('subgood', ['subgood.jpg', 'subfalse.jpg'])
-        subfalse          = self.setup_subgal('subfalse', ['subgood.jpg', 'subfalse.jpg'])
-        good_subdir_path  = os.path.join(self.source_dir, subgood.name, 'subgood.jpg')
-        false_subdir_path = os.path.join(self.source_dir, subfalse.name, 'subfalse.jpg')
-        good     = GExiv2.Metadata(good_path)
-        good2    = GExiv2.Metadata(good_path2)
-        false    = GExiv2.Metadata(false_path)
-        good_sd  = GExiv2.Metadata(good_subdir_path)
-        false_sd = GExiv2.Metadata(false_subdir_path)
-        good['Iptc.Application2.Keywords']     = 'lazygal'
-        good['Xmp.dc.subject']                 = 'lazygal2'
-        good.save_file()
-        good2['Iptc.Application2.Keywords']    = 'lazygalagain'
-        good2['Xmp.dc.subject']                = 'lazygal'
-        good2.save_file()
-        false['Iptc.Application2.Keywords']    = 'another_tag'
-        false.save_file()
-        good_sd['Iptc.Application2.Keywords']  = 'lazygal'
-        good_sd['Xmp.dc.subject']              = 'lazygal2'
-        good_sd.save_file()
-        false_sd['Iptc.Application2.Keywords'] = 'lazygal_lazygal'
-        false_sd['Xmp.dc.subject']             = 'lazygal2'
-        false_sd.save_file()
+        tagfound_path           = self.add_img(self.source_dir, 'tagfound.jpg')
+        tagfound2_path          = self.add_img(self.source_dir, 'tagfound2.jpg')
+        tagnotfound_path        = self.add_img(self.source_dir, 'tagnotfound.jpg')
+        untagged_path           = self.add_img(self.source_dir, 'untagged.jpg')
+        sdir_tagfound           = self.setup_subgal('sdir_tagfound', ['sdir_tagfound.jpg', 'sdir_tagnotfound.jpg'])
+        sdir_tagnotfound        = self.setup_subgal('sdir_tagnotfound', ['sdir_tagfound.jpg', 'sdir_tagnotfound.jpg'])
+        sdir_untagged           = self.setup_subgal('sdir_untagged', ['untagged.jpg'])
+        tagfound_subdir_path    = os.path.join(self.source_dir, sdir_tagfound.name, 'sdir_tagfound.jpg')
+        tagnotfound_subdir_path = os.path.join(self.source_dir, sdir_tagnotfound.name, 'sdir_tagnotfound.jpg')
+        tagfound       = GExiv2.Metadata(tagfound_path)
+        tagfound2      = GExiv2.Metadata(tagfound2_path)
+        tagnotfound    = GExiv2.Metadata(tagnotfound_path)
+        tagfound_sd    = GExiv2.Metadata(tagfound_subdir_path)
+        tagnotfound_sd = GExiv2.Metadata(tagnotfound_subdir_path)
+        tagfound['Iptc.Application2.Keywords']       = 'lazygal'
+        tagfound['Xmp.dc.subject']                   = 'lazygal2'
+        tagfound.save_file()
+        tagfound2['Iptc.Application2.Keywords']      = 'lazygalagain'
+        tagfound2['Xmp.dc.subject']                  = 'lazygal'
+        tagfound2.save_file()
+        tagnotfound['Iptc.Application2.Keywords']    = 'another_tag'
+        tagnotfound.save_file()
+        tagfound_sd['Iptc.Application2.Keywords']    = 'lazygal'
+        tagfound_sd['Xmp.dc.subject']                = 'lazygal2'
+        tagfound_sd.save_file()
+        tagnotfound_sd['Iptc.Application2.Keywords'] = 'lazygal_lazygal'
+        tagnotfound_sd['Xmp.dc.subject']             = 'lazygal2'
+        tagnotfound_sd.save_file()
 
         # generate album
         dest_dir = self.get_working_path()
         self.album.generate(dest_dir)
 
         try:
-            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'good_thumb.jpg')))
-            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'good2_thumb.jpg')))
-            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'false_thumb.jpg')))
-            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'subgood', 'subgood_thumb.jpg')))
-            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'subfalse', 'subfalse_thumb.jpg')))
-            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'subfalse')))
+            self.assertTrue(os.path.isdir(os.path.join(dest_dir, 'sdir_tagfound')))
+            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'tagfound_thumb.jpg')))
+            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'tagfound2_thumb.jpg')))
+            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'tagnotfound_thumb.jpg')))
+            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'sdir_tagfound', 'sdir_tagfound_thumb.jpg')))
+            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'sdir_tagnotfound', 'sdir_tagnotfound_thumb.jpg')))
+            self.assertFalse(os.path.isdir(os.path.join(dest_dir, 'sdir_tagnotfound')))
+            self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'sdir_untagged', 'untagged.jpg')))
+            self.assertFalse(os.path.isdir(os.path.join(dest_dir, 'sdir_untagged')))
         except AssertionError:
             print "\n contents of dest_dir : "
             print os.listdir(dest_dir)
@@ -288,20 +396,20 @@ class TestGenerators(LazygalTestGen):
 
         # We need at least two pictures to display, because lazygal generates a
         # zip archive only if there is more than one picture.
-        good_path = self.add_img(self.source_dir, 'good.jpg')
-        good_path2 = self.add_img(self.source_dir, 'good2.jpg')
-        false_path = self.add_img(self.source_dir, 'false.jpg')
-        good = GExiv2.Metadata(good_path)
-        good2 = GExiv2.Metadata(good_path2)
-        false = GExiv2.Metadata(false_path)
-        good['Iptc.Application2.Keywords'] = 'lazygal'
-        good['Xmp.dc.subject'] = 'lazygal2'
-        good.save_file()
-        good2['Iptc.Application2.Keywords'] = 'lazygalagain'
-        good2['Xmp.dc.subject'] = 'lazygal'
-        good2.save_file()
-        false['Iptc.Application2.Keywords'] = 'another_tag'
-        false.save_file()
+        tagfound_path    = self.add_img(self.source_dir, 'tagfound.jpg')
+        tagfound_path2   = self.add_img(self.source_dir, 'tagfound2.jpg')
+        tagnotfound_path = self.add_img(self.source_dir, 'tagnotfound.jpg')
+        tagfound    = GExiv2.Metadata(tagfound_path)
+        tagfound2   = GExiv2.Metadata(tagfound_path2)
+        tagnotfound = GExiv2.Metadata(tagnotfound_path)
+        tagfound['Iptc.Application2.Keywords']    = 'lazygal'
+        tagfound['Xmp.dc.subject']                = 'lazygal2'
+        tagfound.save_file()
+        tagfound2['Iptc.Application2.Keywords']   = 'lazygalagain'
+        tagfound2['Xmp.dc.subject']               = 'lazygal'
+        tagfound2.save_file()
+        tagnotfound['Iptc.Application2.Keywords'] = 'another_tag'
+        tagnotfound.save_file()
 
         # generate album
         dest_dir = self.get_working_path()
@@ -309,8 +417,8 @@ class TestGenerators(LazygalTestGen):
 
         try:
             self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'src.zip')))
-            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'good_thumb.jpg')))
-            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'good2_thumb.jpg')))
+            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'tagfound_thumb.jpg')))
+            self.assertTrue(os.path.isfile(os.path.join(dest_dir, 'tagfound2_thumb.jpg')))
             self.assertFalse(os.path.isfile(os.path.join(dest_dir, 'false_thumb.jpg')))
         except AssertionError:
             print "\n contents of dest_dir : "
